Client version 2 — python-copr 1.63 documentation

# Client version 2

Warning

Client version 2 is obsolete, please use Client version 3 instead.

New package copr.ClientV2 supports APIv2 and should eventually replace older one. New API and Client_v2 provides more simple and uniform approach for communication with the Copr service.

Client mostly reflects resource based API nature. Client object offers range of methods to query from service. Response objects contains requested information and also provides helper methods to execute new requests in the context of retrieved objects.

- Client initialization
- Resources
- Error handling

## Resources info

- Project
- Project chroot
- Build
- Build task
- Mock chroot

## Autodoc

- General
- CoprClient
- Handlers
  - Project
  - Project chroot
  - Build
  - Build task
  - Mock chroot
- Resources
  - Project
  - Project chroot
  - Build
  - Build task
  - Mock chroot
  - Operation result
- Entities